#
# spec file for package ghc-persistent-template
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent-template
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.8.2.3
Release:        bp153.1.19
Summary:        Type-safe, non-relational, multi-backend persistence
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-http-api-data-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-path-pieces-devel
BuildRequires:  ghc-persistent-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-th-lift-instances-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/persistent-template>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Sat Feb  8 2020 psimons@suse.com
- Update persistent-template to version 2.8.2.3.
  [#]# 2.8.2.3
  * Require extensions in a more friendly manner. [#1030](https://github.com/yesodweb/persistent/pull/1030)
  * Specify a strategy for all deriving clauses, which avoids the `-Wmissing-deriving-strategy` warning introduced in GHC 8.8.2. [#1030](https://github.com/yesodweb/persistent/pull/1030)
  [#]# 2.8.2.2
  * Fix the `mkPersist` function to not require importing the classes explicitly. [#1027](https://github.com/yesodweb/persistent/pull/1027)
* Fri Feb  7 2020 psimons@suse.com
- Update persistent-template to version 2.8.2.1.
  [#]# 2.8.2.1
  * Fix the test-suite for persistent-template. [#1023](https://github.com/yesodweb/persistent/pull/1023)
* Wed Jan 29 2020 psimons@suse.com
- Update persistent-template to version 2.8.2.
  [#]# 2.8.2
  * Add `fieldError` to the export list of `Database.Persist.TH` [#1008](https://github.com/yesodweb/persistent/pull/1008)
  [#]# 2.8.1
  * Let the user pass instances that will be derived for record and for key types (https://github.com/yesodweb/persistent/pull/990
* Tue Jan 14 2020 psimons@suse.com
- Update persistent-template to version 2.8.0.1.
  [#]# 2.8.0.1
  * Small optimization/code cleanup to generated Template Haskell code size, by slimming the implementation of to/fromPersistValue for Entities. [#1014](https://github.com/yesodweb/persistent/pull/1014)
* Sat Jan  4 2020 psimons@suse.com
- Update persistent-template to version 2.8.0.
  [#]# 2.8.0
  * Reduces the amount of code generated by Template Haskell. The amount of code generated for a certain function was O(N^2) with respect to the number of fields on a given Entity. This change shows dramatic improvements in benchmarks for compiling Persistent models. [#]()
  * Drops support for GHC 8.0, so that `DerivingStrategies` can be used by `persistent-template`
  * `persistent-template` now requires `DerivingStrategies`, `GeneralizedNewtypeDeriving`, and `StandaloneDeriving` to be enabled in the file where Persistent entities are created
  * Fixes a long-standing issue where persistent-template would fail when `DeriveAnyClass` was enabled (See #578)
  * [#1002](https://github.com/yesodweb/persistent/pull/1002)
* Thu Jan  2 2020 psimons@suse.com
- Update persistent-template to version 2.7.4.
  [#]# 2.7.4
  * Remove an overlapping instance for `Lift a`. [#998](https://github.com/yesodweb/persistent/pull/998)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Oct 29 2019 psimons@suse.com
- Update persistent-template to version 2.7.3.
  [#]# Unreleased changes
  [#]# 2.7.3
  * Update module documentation for `Database.Persist.TH` to better describe the purpose of the module [#968](https://github.com/yesodweb/persistent/pull/968)
  * Support template-haskell-2.15 [#959](https://github.com/yesodweb/persistent/pull/959)
* Thu Jul 18 2019 psimons@suse.com
- Update persistent-template to version 2.7.2.
  [#]# 2.7.2
  * Expose the knot tying logic of `parseReferences` so that users can build
    migrations from independently define entities at runtime [#932](https://github.com/yesodweb/persistent/pull/932)
* Tue May  7 2019 psimons@suse.com
- Update persistent-template to version 2.7.1.
  [#]# 2.7.1
  * Add the `mkEntityDefList` function to work around [#902](https://github.com/yesodweb/persistent/issues/902). [#904](https://github.com/yesodweb/persistent/pull/904)
* Thu Apr 18 2019 psimons@suse.com
- Update persistent-template to version 2.7.0.
  [#]# 2.7.0
  * Depends on `persistent-2.10.0` which provides the `OnlyOneUniqueKey` and `AtLeastOneUniqueKey` classes. Automatically generates instances for these classes based on how many unique keys the entity definition gets. This changes requires `UndecidableInstances` to be enabled on each module that generates entity definitions. [#885](https://github.com/yesodweb/persistent/pull/885)
  * Removed deprecated `sqlOnlySettings`. Please use `sqlSettings` instead. [#894](https://github.com/yesodweb/persistent/pull/894)
* Mon Jan 28 2019 psimons@suse.com
- Update persistent-template to version 2.6.0.
  [#]# 2.6.0
  * [persistent#846](https://github.com/yesodweb/persistent/pull/846): Improve error message when marshalling fails
  * [persistent#826](https://github.com/yesodweb/persistent/pull/826): Change `Unique` derive `Show`
* Sun Dec  2 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support http-api-data 0.4.x.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed Jul 18 2018 psimons@suse.com
- Revise cabal build file to specify more accurate dependencies.
* Mon May 14 2018 psimons@suse.com
- Update persistent-template to version 2.5.4 revision 1.
  * [persistent#778](https://github.com/yesodweb/persistent/issues/778): Add `persistManyFileWith`.
  * Slight improvement to the error message when a Persistent field can't be parsed from database results
  * Exposed `parseReferences` to allow custom QuasiQuoters
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 2.5.2 revision 1.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 2.5.2 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 2.5.1.6 revision 2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 2.5.1.6 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.1.8.1 revision 0 with cabal2obs.
* Sat May 14 2016 mimi.vx@gmail.com
- update to 2.1.8.1
  * fix a bad Eq instance /= definition for Key when mpsGenetric=True
* Tue Apr 26 2016 mimi.vx@gmail.com
-update to 2.1.8
  * Support for GHC 8
  * aeson 0.11
  * transformers 0.5
* Thu Mar 10 2016 mimi.vx@gmail.com
- update to 2.1.6
* Sun Dec 27 2015 mimi.vx@gmail.com
- update to 2.1.5
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
